@@ -41,6 +41,7 @@ PARAM_FLAG("flag1", "Input flag, must be specified.", "f");
 PARAM_FLAG("flag2", "Input flag, must not be specified.", "F");
 PARAM_MATRIX_IN("matrix_in", "Input matrix.", "m");
 PARAM_UMATRIX_IN("umatrix_in", "Input unsigned matrix.", "u");
+PARAM_TMATRIX_IN("tmatrix_in", "Input (transposed) matrix.", "");
 PARAM_COL_IN("col_in", "Input column.", "c");
 PARAM_UCOL_IN("ucol_in", "Input unsigned column.", "");
 PARAM_ROW_IN("row_in", "Input row.", "");
@@ -94,6 +95,26 @@ void BINDING_FUNCTION(util::Params& params, util::Timers& /* timers */)
       params.Get<double>("double_out") = 5.0;
   }
 
+  // If a transposed input matrix is specified, it is expected to be the same as
+  // the (now required) input matrix.
+  if (params.Has("tmatrix_in"))
+  {
+    if (!params.Has("matrix_in"))
+    {
+      throw std::runtime_error("If tmatrix_in is specified, then matrix_in is "
+          "required!");
+    }
+
+    arma::mat tmat = params.Get<arma::mat>("tmatrix_in");
+    arma::mat mat = params.Get<arma::mat>("matrix_in");
+
+    if (!arma::approx_equal(tmat.t(), mat, "reldiff", 0.001))
+    {
+      throw std::runtime_error("Transposed tmatrix_in and matrix_in are not "
+          "equal!");
+    }
+  }
+
   // Input matrices should be at least 5 rows; the 5th row will be dropped and
   // the 3rd row will be multiplied by two.
   if (params.Has("matrix_in"))
@@ -191,11 +212,15 @@ void BINDING_FUNCTION(util::Params& params, util::Timers& /* timers */)
         {
           if (ceil(m(i, c)) != m(i, c))
             throw std::invalid_argument("non-integer value in categorical!");
-          else if (m(i, c) <= 0)
-            throw std::invalid_argument("negative/zero value in categorical!");
-          else if (size_t(m(i, c)) > di.NumMappings(i))
+          else if (m(i, c) < 0)
+            throw std::invalid_argument("negative value in categorical!");
+          else if (size_t(m(i, c)) >= di.NumMappings(i))
             throw std::invalid_argument("value outside number of categories!");
         }
+
+        // Since this goes back to Julia as a regular matrix, we have to
+        // manually convert the categorical features to be one-indexed.
+        m.row(i) += 1.0;
       }
     }
 
